@@ -139,7 +139,9 @@ dlgSave.nativeGUI <- function (default, title, filters = dlgFilters["All", ],
     ## TODO: filters are implemented differently on the Mac => how to do this???
 	if (!is.matrix(filters)) filters <- matrix(filters, ncol = 2, byrow = TRUE)
 	## Display a modal file save selector with native Mac dialog box
-	if (.Platform$GUI == "AQUA") app <- "(name of application \"R\")" else
+	#if (.Platform$GUI == "AQUA") app <- "(name of application \"R\")" else
+	## This works from Mac OS X 10.5 Leopard:
+	if (.Platform$GUI == "AQUA") app <- "(name of application id \"Rgui\")" else
 		if (.isJGR()) app <- "\"JGR\"" else app <- "\"Terminal\""
 	## Avoid displaying warning message when the user clicks on 'Cancel'
 	owarn <- getOption("warn")
